summaryrefslogtreecommitdiffstats
path: root/src/gui/painting
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/painting')
-rw-r--r--src/gui/painting/qbezier_p.h5
-rw-r--r--src/gui/painting/qbrush.h6
-rw-r--r--src/gui/painting/qcolortransfertable_p.h16
-rw-r--r--src/gui/painting/qdrawhelper_p.h2
-rw-r--r--src/gui/painting/qpainter.h24
-rw-r--r--src/gui/painting/qpainter_p.h4
-rw-r--r--src/gui/painting/qpainterpath.h8
-rw-r--r--src/gui/painting/qpainterpath_p.h17
-rw-r--r--src/gui/painting/qpathclipper_p.h2
-rw-r--r--src/gui/painting/qpdf_p.h24
-rw-r--r--src/gui/painting/qpen.h4
-rw-r--r--src/gui/painting/qpixellayout_p.h34
-rw-r--r--src/gui/painting/qpolygon.h34
-rw-r--r--src/gui/painting/qrangecollection.h2
-rw-r--r--src/gui/painting/qrangecollection_p.h2
-rw-r--r--src/gui/painting/qrbtree_p.h4
-rw-r--r--src/gui/painting/qstroker_p.h8
-rw-r--r--src/gui/painting/qtriangulator_p.h14
18 files changed, 106 insertions, 104 deletions
diff --git a/src/gui/painting/qbezier_p.h b/src/gui/painting/qbezier_p.h
index 1c49f82416..bf712822a2 100644
--- a/src/gui/painting/qbezier_p.h
+++ b/src/gui/painting/qbezier_p.h
@@ -52,12 +52,11 @@
//
#include <QtGui/private/qtguiglobal_p.h>
-#include "QtCore/qpoint.h"
#include "QtCore/qline.h"
-#include "QtCore/qrect.h"
-#include "QtCore/qvector.h"
#include "QtCore/qlist.h"
#include "QtCore/qpair.h"
+#include "QtCore/qpoint.h"
+#include "QtCore/qrect.h"
#include "QtGui/qtransform.h"
#include <private/qdatabuffer_p.h>
diff --git a/src/gui/painting/qbrush.h b/src/gui/painting/qbrush.h
index 621387615b..281789c838 100644
--- a/src/gui/painting/qbrush.h
+++ b/src/gui/painting/qbrush.h
@@ -41,14 +41,14 @@
#define QBRUSH_H
#include <QtGui/qtguiglobal.h>
+#include <QtCore/qlist.h>
#include <QtCore/qpair.h>
#include <QtCore/qpoint.h>
-#include <QtCore/qvector.h>
#include <QtCore/qscopedpointer.h>
#include <QtGui/qcolor.h>
-#include <QtGui/qtransform.h>
#include <QtGui/qimage.h>
#include <QtGui/qpixmap.h>
+#include <QtGui/qtransform.h>
QT_BEGIN_NAMESPACE
@@ -163,7 +163,7 @@ inline bool QBrush::isDetached() const { return d->ref.loadRelaxed() == 1; }
class QGradientPrivate;
typedef QPair<qreal, QColor> QGradientStop;
-typedef QVector<QGradientStop> QGradientStops;
+typedef QList<QGradientStop> QGradientStops;
class Q_GUI_EXPORT QGradient
{
diff --git a/src/gui/painting/qcolortransfertable_p.h b/src/gui/painting/qcolortransfertable_p.h
index c8b2f7bd92..c945b55576 100644
--- a/src/gui/painting/qcolortransfertable_p.h
+++ b/src/gui/painting/qcolortransfertable_p.h
@@ -54,7 +54,7 @@
#include <QtGui/private/qtguiglobal_p.h>
#include "qcolortransferfunction_p.h"
-#include <QVector>
+#include <QList>
#include <cmath>
QT_BEGIN_NAMESPACE
@@ -66,13 +66,11 @@ public:
QColorTransferTable() noexcept
: m_tableSize(0)
{ }
- QColorTransferTable(uint32_t size, const QVector<uint8_t> &table) noexcept
- : m_tableSize(size)
- , m_table8(table)
+ QColorTransferTable(uint32_t size, const QList<uint8_t> &table) noexcept
+ : m_tableSize(size), m_table8(table)
{ }
- QColorTransferTable(uint32_t size, const QVector<uint16_t> &table) noexcept
- : m_tableSize(size)
- , m_table16(table)
+ QColorTransferTable(uint32_t size, const QList<uint16_t> &table) noexcept
+ : m_tableSize(size), m_table16(table)
{ }
bool isValid() const
@@ -208,8 +206,8 @@ public:
friend inline bool operator==(const QColorTransferTable &t1, const QColorTransferTable &t2);
uint32_t m_tableSize;
- QVector<uint8_t> m_table8;
- QVector<uint16_t> m_table16;
+ QList<uint8_t> m_table8;
+ QList<uint16_t> m_table16;
};
inline bool operator!=(const QColorTransferTable &t1, const QColorTransferTable &t2)
diff --git a/src/gui/painting/qdrawhelper_p.h b/src/gui/painting/qdrawhelper_p.h
index 387481a915..13629f1fea 100644
--- a/src/gui/painting/qdrawhelper_p.h
+++ b/src/gui/painting/qdrawhelper_p.h
@@ -317,7 +317,7 @@ struct QTextureData
int y2;
qsizetype bytesPerLine;
QImage::Format format;
- const QVector<QRgb> *colorTable;
+ const QList<QRgb> *colorTable;
bool hasAlpha;
enum Type {
Plain,
diff --git a/src/gui/painting/qpainter.h b/src/gui/painting/qpainter.h
index 4d2efb1e67..498e443108 100644
--- a/src/gui/painting/qpainter.h
+++ b/src/gui/painting/qpainter.h
@@ -279,22 +279,22 @@ public:
inline void drawLine(const QPointF &p1, const QPointF &p2);
void drawLines(const QLineF *lines, int lineCount);
- inline void drawLines(const QVector<QLineF> &lines);
+ inline void drawLines(const QList<QLineF> &lines);
void drawLines(const QPointF *pointPairs, int lineCount);
- inline void drawLines(const QVector<QPointF> &pointPairs);
+ inline void drawLines(const QList<QPointF> &pointPairs);
void drawLines(const QLine *lines, int lineCount);
- inline void drawLines(const QVector<QLine> &lines);
+ inline void drawLines(const QList<QLine> &lines);
void drawLines(const QPoint *pointPairs, int lineCount);
- inline void drawLines(const QVector<QPoint> &pointPairs);
+ inline void drawLines(const QList<QPoint> &pointPairs);
inline void drawRect(const QRectF &rect);
inline void drawRect(int x1, int y1, int w, int h);
inline void drawRect(const QRect &rect);
void drawRects(const QRectF *rects, int rectCount);
- inline void drawRects(const QVector<QRectF> &rectangles);
+ inline void drawRects(const QList<QRectF> &rectangles);
void drawRects(const QRect *rects, int rectCount);
- inline void drawRects(const QVector<QRect> &rectangles);
+ inline void drawRects(const QList<QRect> &rectangles);
void drawEllipse(const QRectF &r);
void drawEllipse(const QRect &r);
@@ -500,22 +500,22 @@ inline void QPainter::drawLine(const QPointF &p1, const QPointF &p2)
drawLine(QLineF(p1, p2));
}
-inline void QPainter::drawLines(const QVector<QLineF> &lines)
+inline void QPainter::drawLines(const QList<QLineF> &lines)
{
drawLines(lines.constData(), lines.size());
}
-inline void QPainter::drawLines(const QVector<QLine> &lines)
+inline void QPainter::drawLines(const QList<QLine> &lines)
{
drawLines(lines.constData(), lines.size());
}
-inline void QPainter::drawLines(const QVector<QPointF> &pointPairs)
+inline void QPainter::drawLines(const QList<QPointF> &pointPairs)
{
drawLines(pointPairs.constData(), pointPairs.size() / 2);
}
-inline void QPainter::drawLines(const QVector<QPoint> &pointPairs)
+inline void QPainter::drawLines(const QList<QPoint> &pointPairs)
{
drawLines(pointPairs.constData(), pointPairs.size() / 2);
}
@@ -566,12 +566,12 @@ inline void QPainter::drawRect(const QRect &r)
drawRects(&r, 1);
}
-inline void QPainter::drawRects(const QVector<QRectF> &rects)
+inline void QPainter::drawRects(const QList<QRectF> &rects)
{
drawRects(rects.constData(), rects.size());
}
-inline void QPainter::drawRects(const QVector<QRect> &rects)
+inline void QPainter::drawRects(const QList<QRect> &rects)
{
drawRects(rects.constData(), rects.size());
}
diff --git a/src/gui/painting/qpainterpath.h b/src/gui/painting/qpainterpath.h
index b72a5d3298..c6bb68e35a 100644
--- a/src/gui/painting/qpainterpath.h
+++ b/src/gui/painting/qpainterpath.h
@@ -43,9 +43,9 @@
#include <QtGui/qtguiglobal.h>
#include <QtGui/qtransform.h>
#include <QtCore/qglobal.h>
-#include <QtCore/qrect.h>
#include <QtCore/qline.h>
-#include <QtCore/qvector.h>
+#include <QtCore/qlist.h>
+#include <QtCore/qrect.h>
#include <QtCore/qscopedpointer.h>
QT_BEGIN_NAMESPACE
@@ -256,8 +256,8 @@ public:
qreal curveThreshold() const;
void setDashPattern(Qt::PenStyle);
- void setDashPattern(const QVector<qreal> &dashPattern);
- QVector<qreal> dashPattern() const;
+ void setDashPattern(const QList<qreal> &dashPattern);
+ QList<qreal> dashPattern() const;
void setDashOffset(qreal offset);
qreal dashOffset() const;
diff --git a/src/gui/painting/qpainterpath_p.h b/src/gui/painting/qpainterpath_p.h
index d52243b0df..57668190db 100644
--- a/src/gui/painting/qpainterpath_p.h
+++ b/src/gui/painting/qpainterpath_p.h
@@ -98,7 +98,7 @@ public:
private:
QAtomicInt ref;
- QVector<QPainterPath::Element> elements;
+ QList<QPainterPath::Element> elements;
};
class QPainterPathStrokerPrivate
@@ -107,7 +107,7 @@ public:
QPainterPathStrokerPrivate();
QStroker stroker;
- QVector<qfixed> dashPattern;
+ QList<qfixed> dashPattern;
qreal dashOffset;
};
@@ -117,20 +117,19 @@ class QVectorPathConverter;
class QVectorPathConverter
{
public:
- QVectorPathConverter(const QVector<QPainterPath::Element> &path, uint fillRule, bool convex)
+ QVectorPathConverter(const QList<QPainterPath::Element> &path, uint fillRule, bool convex)
: pathData(path, fillRule, convex),
- path(pathData.points.data(), path.size(),
- pathData.elements.data(), pathData.flags) {}
+ path(pathData.points.data(), path.size(), pathData.elements.data(), pathData.flags)
+ {
+ }
const QVectorPath &vectorPath() {
return path;
}
struct QVectorPathData {
- QVectorPathData(const QVector<QPainterPath::Element> &path, uint fillRule, bool convex)
- : elements(path.size()),
- points(path.size() * 2),
- flags(0)
+ QVectorPathData(const QList<QPainterPath::Element> &path, uint fillRule, bool convex)
+ : elements(path.size()), points(path.size() * 2), flags(0)
{
int ptsPos = 0;
bool isLines = true;
diff --git a/src/gui/painting/qpathclipper_p.h b/src/gui/painting/qpathclipper_p.h
index 9444a87b71..6f712c396e 100644
--- a/src/gui/painting/qpathclipper_p.h
+++ b/src/gui/painting/qpathclipper_p.h
@@ -282,7 +282,7 @@ private:
QDataBuffer<QPathEdge> m_edges;
QDataBuffer<QPathVertex> m_vertices;
- QVector<qreal> m_splitPoints;
+ QList<qreal> m_splitPoints;
QPathSegments m_segments;
};
diff --git a/src/gui/painting/qpdf_p.h b/src/gui/painting/qpdf_p.h
index 4ff540e67b..c277539cfa 100644
--- a/src/gui/painting/qpdf_p.h
+++ b/src/gui/painting/qpdf_p.h
@@ -55,12 +55,12 @@
#ifndef QT_NO_PDF
+#include "QtCore/qlist.h"
#include "QtCore/qstring.h"
-#include "QtCore/qvector.h"
-#include "private/qstroker_p.h"
-#include "private/qpaintengine_p.h"
#include "private/qfontengine_p.h"
#include "private/qfontsubset_p.h"
+#include "private/qpaintengine_p.h"
+#include "private/qstroker_p.h"
#include "qpagelayout.h"
QT_BEGIN_NAMESPACE
@@ -147,11 +147,11 @@ class QPdfPage : public QPdf::ByteStream
public:
QPdfPage();
- QVector<uint> images;
- QVector<uint> graphicStates;
- QVector<uint> patterns;
- QVector<uint> fonts;
- QVector<uint> annotations;
+ QList<uint> images;
+ QList<uint> graphicStates;
+ QList<uint> patterns;
+ QList<uint> fonts;
+ QList<uint> annotations;
void streamImage(int w, int h, int object);
@@ -265,7 +265,7 @@ public:
QPointF brushOrigin;
QBrush brush;
QPen pen;
- QVector<QPainterPath> clips;
+ QList<QPainterPath> clips;
bool clipEnabled;
bool allClipped;
bool hasPen;
@@ -309,7 +309,7 @@ private:
void embedFont(QFontSubset *font);
qreal calcUserUnit() const;
- QVector<int> xrefPositions;
+ QList<int> xrefPositions;
QDataStream* stream;
int streampos;
@@ -340,10 +340,10 @@ private:
// various PDF objects
int pageRoot, embeddedfilesRoot, namesRoot, catalog, info, graphicsState, patternColorSpace;
- QVector<uint> pages;
+ QList<uint> pages;
QHash<qint64, uint> imageCache;
QHash<QPair<uint, uint>, uint > alphaCache;
- QVector<AttachmentInfo> fileCache;
+ QList<AttachmentInfo> fileCache;
QByteArray xmpDocumentMetadata;
};
diff --git a/src/gui/painting/qpen.h b/src/gui/painting/qpen.h
index 10b11d1d85..38282bda39 100644
--- a/src/gui/painting/qpen.h
+++ b/src/gui/painting/qpen.h
@@ -79,8 +79,8 @@ public:
Qt::PenStyle style() const;
void setStyle(Qt::PenStyle);
- QVector<qreal> dashPattern() const;
- void setDashPattern(const QVector<qreal> &pattern);
+ QList<qreal> dashPattern() const;
+ void setDashPattern(const QList<qreal> &pattern);
qreal dashOffset() const;
void setDashOffset(qreal doffset);
diff --git a/src/gui/painting/qpixellayout_p.h b/src/gui/painting/qpixellayout_p.h
index 99a781b49b..0cbf514ded 100644
--- a/src/gui/painting/qpixellayout_p.h
+++ b/src/gui/painting/qpixellayout_p.h
@@ -51,7 +51,7 @@
// We mean it.
//
-#include <QtCore/qvector.h>
+#include <QtCore/qlist.h>
#include <QtGui/qimage.h>
#include <QtGui/qrgba64.h>
@@ -280,20 +280,26 @@ struct QDitherInfo {
int y;
};
-typedef const uint *(QT_FASTCALL *FetchAndConvertPixelsFunc)(uint *buffer, const uchar *src, int index, int count,
- const QVector<QRgb> *clut, QDitherInfo *dither);
-typedef void (QT_FASTCALL *ConvertAndStorePixelsFunc)(uchar *dest, const uint *src, int index, int count,
- const QVector<QRgb> *clut, QDitherInfo *dither);
-
-typedef const QRgba64 *(QT_FASTCALL *FetchAndConvertPixelsFunc64)(QRgba64 *buffer, const uchar *src, int index, int count,
- const QVector<QRgb> *clut, QDitherInfo *dither);
-typedef void (QT_FASTCALL *ConvertAndStorePixelsFunc64)(uchar *dest, const QRgba64 *src, int index, int count,
- const QVector<QRgb> *clut, QDitherInfo *dither);
-
-typedef void (QT_FASTCALL *ConvertFunc)(uint *buffer, int count, const QVector<QRgb> *clut);
-typedef void (QT_FASTCALL *Convert64Func)(quint64 *buffer, int count, const QVector<QRgb> *clut);
+typedef const uint *(QT_FASTCALL *FetchAndConvertPixelsFunc)(uint *buffer, const uchar *src,
+ int index, int count,
+ const QList<QRgb> *clut,
+ QDitherInfo *dither);
+typedef void(QT_FASTCALL *ConvertAndStorePixelsFunc)(uchar *dest, const uint *src, int index,
+ int count, const QList<QRgb> *clut,
+ QDitherInfo *dither);
+
+typedef const QRgba64 *(QT_FASTCALL *FetchAndConvertPixelsFunc64)(QRgba64 *buffer, const uchar *src,
+ int index, int count,
+ const QList<QRgb> *clut,
+ QDitherInfo *dither);
+typedef void(QT_FASTCALL *ConvertAndStorePixelsFunc64)(uchar *dest, const QRgba64 *src, int index,
+ int count, const QList<QRgb> *clut,
+ QDitherInfo *dither);
+
+typedef void(QT_FASTCALL *ConvertFunc)(uint *buffer, int count, const QList<QRgb> *clut);
+typedef void(QT_FASTCALL *Convert64Func)(quint64 *buffer, int count, const QList<QRgb> *clut);
typedef const QRgba64 *(QT_FASTCALL *ConvertTo64Func)(QRgba64 *buffer, const uint *src, int count,
- const QVector<QRgb> *clut, QDitherInfo *dither);
+ const QList<QRgb> *clut, QDitherInfo *dither);
typedef void (QT_FASTCALL *RbSwapFunc)(uchar *dst, const uchar *src, int count);
typedef void (*MemRotateFunc)(const uchar *srcPixels, int w, int h, int sbpl, uchar *destPixels, int dbpl);
diff --git a/src/gui/painting/qpolygon.h b/src/gui/painting/qpolygon.h
index 8812cb6a93..57c9a3fa46 100644
--- a/src/gui/painting/qpolygon.h
+++ b/src/gui/painting/qpolygon.h
@@ -41,7 +41,7 @@
#define QPOLYGON_H
#include <QtGui/qtguiglobal.h>
-#include <QtCore/qvector.h>
+#include <QtCore/qlist.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
@@ -51,21 +51,21 @@ class QTransform;
class QRect;
class QVariant;
-class Q_GUI_EXPORT QPolygon : public QVector<QPoint>
+class Q_GUI_EXPORT QPolygon : public QList<QPoint>
{
public:
inline QPolygon() {}
inline ~QPolygon() {}
inline explicit QPolygon(int size);
- inline /*implicit*/ QPolygon(const QVector<QPoint> &v) : QVector<QPoint>(v) {}
- /*implicit*/ QPolygon(QVector<QPoint> &&v) noexcept : QVector<QPoint>(std::move(v)) {}
+ inline /*implicit*/ QPolygon(const QList<QPoint> &v) : QList<QPoint>(v) { }
+ /*implicit*/ QPolygon(QList<QPoint> &&v) noexcept : QList<QPoint>(std::move(v)) { }
QPolygon(const QRect &r, bool closed=false);
QPolygon(int nPoints, const int *points);
- QPolygon(const QPolygon &other) : QVector<QPoint>(other) {}
- QPolygon(QPolygon &&other) noexcept : QVector<QPoint>(std::move(other)) {}
+ QPolygon(const QPolygon &other) : QList<QPoint>(other) { }
+ QPolygon(QPolygon &&other) noexcept : QList<QPoint>(std::move(other)) { }
QPolygon &operator=(QPolygon &&other) noexcept { swap(other); return *this; }
- QPolygon &operator=(const QPolygon &other) { QVector<QPoint>::operator=(other); return *this; }
- void swap(QPolygon &other) noexcept { QVector<QPoint>::swap(other); } // prevent QVector<QPoint><->QPolygon swaps
+ QPolygon &operator=(const QPolygon &other) { QList<QPoint>::operator=(other); return *this; }
+ void swap(QPolygon &other) noexcept { QList<QPoint>::swap(other); } // prevent QList<QPoint><->QPolygon swaps
operator QVariant() const;
@@ -97,7 +97,7 @@ public:
};
Q_DECLARE_SHARED(QPolygon)
-inline QPolygon::QPolygon(int asize) : QVector<QPoint>(asize) {}
+inline QPolygon::QPolygon(int size) : QList<QPoint>(size) { }
#ifndef QT_NO_DEBUG_STREAM
Q_GUI_EXPORT QDebug operator<<(QDebug, const QPolygon &);
@@ -132,21 +132,21 @@ inline QPolygon QPolygon::translated(const QPoint &offset) const
class QRectF;
-class Q_GUI_EXPORT QPolygonF : public QVector<QPointF>
+class Q_GUI_EXPORT QPolygonF : public QList<QPointF>
{
public:
inline QPolygonF() {}
inline ~QPolygonF() {}
inline explicit QPolygonF(int size);
- inline /*implicit*/ QPolygonF(const QVector<QPointF> &v) : QVector<QPointF>(v) {}
- /* implicit */ QPolygonF(QVector<QPointF> &&v) noexcept : QVector<QPointF>(std::move(v)) {}
+ inline /*implicit*/ QPolygonF(const QList<QPointF> &v) : QList<QPointF>(v) { }
+ /* implicit */ QPolygonF(QList<QPointF> &&v) noexcept : QList<QPointF>(std::move(v)) { }
QPolygonF(const QRectF &r);
/*implicit*/ QPolygonF(const QPolygon &a);
- inline QPolygonF(const QPolygonF &a) : QVector<QPointF>(a) {}
- QPolygonF(QPolygonF &&other) noexcept : QVector<QPointF>(std::move(other)) {}
+ inline QPolygonF(const QPolygonF &a) : QList<QPointF>(a) { }
+ QPolygonF(QPolygonF &&other) noexcept : QList<QPointF>(std::move(other)) { }
QPolygonF &operator=(QPolygonF &&other) noexcept { swap(other); return *this; }
- QPolygonF &operator=(const QPolygonF &other) { QVector<QPointF>::operator=(other); return *this; }
- inline void swap(QPolygonF &other) { QVector<QPointF>::swap(other); } // prevent QVector<QPointF><->QPolygonF swaps
+ QPolygonF &operator=(const QPolygonF &other) { QList<QPointF>::operator=(other); return *this; }
+ inline void swap(QPolygonF &other) { QList<QPointF>::swap(other); } // prevent QList<QPointF><->QPolygonF swaps
operator QVariant() const;
@@ -172,7 +172,7 @@ public:
};
Q_DECLARE_SHARED(QPolygonF)
-inline QPolygonF::QPolygonF(int asize) : QVector<QPointF>(asize) {}
+inline QPolygonF::QPolygonF(int size) : QList<QPointF>(size) { }
#ifndef QT_NO_DEBUG_STREAM
Q_GUI_EXPORT QDebug operator<<(QDebug, const QPolygonF &);
diff --git a/src/gui/painting/qrangecollection.h b/src/gui/painting/qrangecollection.h
index 310adaab05..b63ceb6b74 100644
--- a/src/gui/painting/qrangecollection.h
+++ b/src/gui/painting/qrangecollection.h
@@ -41,9 +41,9 @@
#define QRANGECOLLECTION_H
#include <QtGui/qtguiglobal.h>
+#include <QtCore/qlist.h>
#include <QtCore/qpair.h>
#include <QtCore/qscopedpointer.h>
-#include <QtCore/qvector.h>
QT_BEGIN_NAMESPACE
diff --git a/src/gui/painting/qrangecollection_p.h b/src/gui/painting/qrangecollection_p.h
index 9f930c18d3..39a52f2a6b 100644
--- a/src/gui/painting/qrangecollection_p.h
+++ b/src/gui/painting/qrangecollection_p.h
@@ -67,7 +67,7 @@ public:
void mergeIntervals();
- QVector<QPair<int, int>> intervals;
+ QList<QPair<int, int>> intervals;
QRangeCollection *q_ptr;
};
diff --git a/src/gui/painting/qrbtree_p.h b/src/gui/painting/qrbtree_p.h
index 42e88889a1..42539bf8e9 100644
--- a/src/gui/painting/qrbtree_p.h
+++ b/src/gui/painting/qrbtree_p.h
@@ -538,8 +538,8 @@ int QRBTree<T>::order(Node *left, Node *right)
if (left == right)
return 0;
- QVector<Node *> leftAncestors;
- QVector<Node *> rightAncestors;
+ QList<Node *> leftAncestors;
+ QList<Node *> rightAncestors;
while (left) {
leftAncestors.push_back(left);
left = left->parent;
diff --git a/src/gui/painting/qstroker_p.h b/src/gui/painting/qstroker_p.h
index 3207f1944b..0a9f55f222 100644
--- a/src/gui/painting/qstroker_p.h
+++ b/src/gui/painting/qstroker_p.h
@@ -263,10 +263,10 @@ public:
QStroker *stroker() const { return m_stroker; }
- static QVector<qfixed> patternForStyle(Qt::PenStyle style);
+ static QList<qfixed> patternForStyle(Qt::PenStyle style);
- void setDashPattern(const QVector<qfixed> &dashPattern) { m_dashPattern = dashPattern; }
- QVector<qfixed> dashPattern() const { return m_dashPattern; }
+ void setDashPattern(const QList<qfixed> &dashPattern) { m_dashPattern = dashPattern; }
+ QList<qfixed> dashPattern() const { return m_dashPattern; }
void setDashOffset(qreal offset) { m_dashOffset = offset; }
qreal dashOffset() const { return m_dashOffset; }
@@ -281,7 +281,7 @@ protected:
void processCurrentSubpath() override;
QStroker *m_stroker;
- QVector<qfixed> m_dashPattern;
+ QList<qfixed> m_dashPattern;
qreal m_dashOffset;
qreal m_stroke_width;
diff --git a/src/gui/painting/qtriangulator_p.h b/src/gui/painting/qtriangulator_p.h
index 177e5e66ed..e07fcae090 100644
--- a/src/gui/painting/qtriangulator_p.h
+++ b/src/gui/painting/qtriangulator_p.h
@@ -52,8 +52,8 @@
//
#include <QtGui/private/qtguiglobal_p.h>
-#include <QtCore/qvector.h>
#include <QtGui/private/qvectorpath_p.h>
+#include <QtCore/qlist.h>
QT_BEGIN_NAMESPACE
@@ -67,13 +67,13 @@ public:
inline Type type() const { return t; }
- inline void setDataUint(const QVector<quint32> &data)
+ inline void setDataUint(const QList<quint32> &data)
{
t = UnsignedInt;
indices32 = data;
}
- inline void setDataUshort(const QVector<quint16> &data)
+ inline void setDataUshort(const QList<quint16> &data)
{
t = UnsignedShort;
indices16 = data;
@@ -96,20 +96,20 @@ public:
private:
Type t;
- QVector<quint32> indices32;
- QVector<quint16> indices16;
+ QList<quint32> indices32;
+ QList<quint16> indices16;
};
struct QTriangleSet
{
// The vertices of a triangle are given by: (x[i[n]], y[i[n]]), (x[j[n]], y[j[n]]), (x[k[n]], y[k[n]]), n = 0, 1, ...
- QVector<qreal> vertices; // [x[0], y[0], x[1], y[1], x[2], ...]
+ QList<qreal> vertices; // [x[0], y[0], x[1], y[1], x[2], ...]
QVertexIndexVector indices; // [i[0], j[0], k[0], i[1], j[1], k[1], i[2], ...]
};
struct QPolylineSet
{
- QVector<qreal> vertices; // [x[0], y[0], x[1], y[1], x[2], ...]
+ QList<qreal> vertices; // [x[0], y[0], x[1], y[1], x[2], ...]
QVertexIndexVector indices; // End of polyline is marked with -1.
};
diff --git a/src/gui/painting/qpainter_p.h b/src/gui/painting/qpainter_p.h
index 9b299ac18d..fe029c66a5 100644
--- a/src/gui/painting/qpainter_p.h
+++ b/src/gui/painting/qpainter_p.h
@@ -102,7 +102,7 @@ inline bool qbrush_has_transform(const QBrush &b) { return data_ptr(b)->transfor
class QPainterClipInfo
{
public:
- QPainterClipInfo() {} // for QVector, don't use
+ QPainterClipInfo() { } // for QList, don't use
enum ClipType { RegionClip, PathClip, RectClip, RectFClip };
QPainterClipInfo(const QPainterPath &p, Qt::ClipOperation op, const QTransform &m) :
@@ -160,7 +160,7 @@ public:
QPainterPath clipPath;
Qt::ClipOperation clipOperation = Qt::NoClip;
QPainter::RenderHints renderHints;
- QVector<QPainterClipInfo> clipInfo; // ### Make me smaller and faster to copy around...
+ QList<QPainterClipInfo> clipInfo; // ### Make me smaller and faster to copy around...
QTransform worldMatrix; // World transformation matrix, not window and viewport
QTransform matrix; // Complete transformation matrix,
QTransform redirectionMatrix;